@@ -1,18 +1,19 @@
-from ..C_M import CM; C = CM()
+from ..ANSI_COLORS import ANSI; C = ANSI()
+from ..MODULES import IMPORT; M = IMPORT()
 
 
-# ————— PING Test —————
+# ————— 𝐏𝐈𝐍𝐆 𝐓𝐞𝐬𝐭 —————
 def PING(host):
     
     print(f"\n{C.X}{C.C} Ping Checker\n"
          f"\n{C.INFO}{C.C} Need Internet Connection...{C.G}\n")
 
-    param = '-n' if C.os.name == 'nt' else '-c'
+    param = '-n' if M.os.name == 'nt' else '-c'
 
     cmd = f'ping {param} 5 {host}'
 
-    if C.subprocess.call(cmd, shell=True) == 0:
+    if M.subprocess.call(cmd, shell=True) == 0:
         exit(f"\n{C.S}{C.P} Status {C.E}{C.G} {host}{C.C} is reachable. {C.G}✔\n")
     else:
-        exit(f"\n{C.S}{C.P} Status {C.E}{C.G} {host}{C.RD} is not reachable. ✘\n"
+        exit(f"\n{C.S}{C.P} Status {C.E}{C.G} {host}{C.R} is not reachable. ✘\n"
             f"\n{C.INFO} {C.C} Need Internet Connection...\n")
\ No newline at end of file
